==> ovito_3.10.5~ds.orig.tar.xz: ovito-v3.10.5/src/ovito/mesh/modifier/SurfaceMeshReplicateModifierDelegate.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2023 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/mesh/Mesh.h>
#include <ovito/stdmod/modifiers/ReplicateModifier.h>

namespace Ovito {

/**
 * \brief Delegate for the ReplicateModifier that operates on surface meshes.
 */
class OVITO_MESHMOD_EXPORT SurfaceMeshReplicateModifierDelegate : public ReplicateModifierDelegate
{
    /// Give the modifier delegate its own metaclass.
    class OOMetaClass : public ReplicateModifierDelegate::OOMetaClass
    {
    public:

        /// Inherit constructor from base class.
        using ReplicateModifierDelegate::OOMetaClass::OOMetaClass;

        /// Indicates which data objects in the given input data collection the modifier delegate is able to operate on.
        virtual QVector<DataObjectReference> getApplicableObjects(const DataCollection& input) const override {
            if(input.containsObject<SurfaceMesh>())
                return { DataObjectReference(&SurfaceMesh::OOClass()) };
            return {};
        }

        /// The name by which Python scripts can refer to this modifier delegate.
        virtual QString pythonDataName() const override { return QStringLiteral("surfaces"); }
    };

    OVITO_CLASS_META(SurfaceMeshReplicateModifierDelegate, OOMetaClass)

    Q_CLASSINFO("DisplayName", "Surfaces");

public:

    /// Constructor.
    Q_INVOKABLE SurfaceMeshReplicateModifierDelegate(ObjectInitializationFlags flags) : ReplicateModifierDelegate(flags) {}

    /// Applies the modifier operation to the data in a pipeline flow state.
    virtual PipelineStatus apply(const ModifierEvaluationRequest& request, PipelineFlowState& state, const PipelineFlowState& inputState, const std::vector<std::reference_wrapper<const PipelineFlowState>>& additionalInputs) override;
};

}   // End of namespace

==> ovito_3.13.1~ds.orig.tar.xz: ovito-v3.13.1/src/ovito/mesh/modifier/SurfaceMeshReplicateModifierDelegate.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2025 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/mesh/Mesh.h>
#include <ovito/stdmod/modifiers/ReplicateModifier.h>

namespace Ovito {

/**
 * \brief Delegate for the ReplicateModifier that operates on surface meshes.
 */
class OVITO_MESHMOD_EXPORT SurfaceMeshReplicateModifierDelegate : public ReplicateModifierDelegate
{
    /// Give the modifier delegate its own metaclass.
    class OOMetaClass : public ReplicateModifierDelegate::OOMetaClass
    {
    public:

        /// Inherit constructor from base class.
        using ReplicateModifierDelegate::OOMetaClass::OOMetaClass;

        /// Indicates which data objects in the given input data collection the modifier delegate is able to operate on.
        virtual QVector<DataObjectReference> getApplicableObjects(const DataCollection& input) const override {
            if(input.containsObject<SurfaceMesh>())
                return { DataObjectReference(&SurfaceMesh::OOClass()) };
            return {};
        }

        /// The name by which Python scripts can refer to this modifier delegate.
        virtual QString pythonDataName() const override { return QStringLiteral("surfaces"); }
    };

    OVITO_CLASS_META(SurfaceMeshReplicateModifierDelegate, OOMetaClass)

public:

    /// Applies this modifier delegate to the data.
    virtual Future<PipelineFlowState> apply(const ModifierEvaluationRequest& request, PipelineFlowState&& state, const PipelineFlowState& originalState, const std::vector<std::reference_wrapper<const PipelineFlowState>>& additionalInputs) override;
};

}   // End of namespace
